@@ -102,9 +102,11 @@ void FortranMagics::reset() {
     empty_            = true;
     gribindex_        = 0;
     legend_todo_      = false;
+
     symbolinput_todo_ = false;
     matrixinput_todo_ = false;
     polyinput_todo_   = false;
+    obsinput_todo_    = false;
 
 
     while (actions_.size()) {
@@ -429,19 +431,23 @@ void FortranMagics::ptephi() {
 }
 void FortranMagics::pobs() {
     actions();
-    action_         = new VisualAction();
-    ObsDecoder* obs = new ObsDecoder();
-    if (obs->defined()) {
-        action_->data(obs);
-        top()->push_back(action_);
-        action_->visdef(new ObsPlotting());
-        return;
+
+    if (!action_ || obsinput_todo_ ) {
+        action_         = new VisualAction();
+        ObsDecoder* obs = new ObsDecoder();
+        if (obs->defined()) {
+            action_->data(obs);
+            top()->push_back(action_);
+           
+        }
+        else {
+            action_ = new VisualAction();
+            action_->data(new ObsJSon());
+            top()->push_back(action_);
+        }
     }
-    action_ = new VisualAction();
-    action_->data(new ObsJSon());
-    top()->push_back(action_);
     action_->visdef(new ObsPlotting());
-    return;
+    
 }
 
 #include "MatrixTestDecoder.h"
@@ -641,7 +647,7 @@ const char* FortranMagics::metainput() {
     StyleEntry style;
     library->getStyle(request, attributes, style);
     ostringstream out;
-    out << style;
+    out << "{" << style << "}";
     static string temp;
     temp = out.str();
     return temp.c_str();
@@ -822,6 +828,8 @@ void FortranMagics::ptext() {
 void FortranMagics::psymb() {
     actions();
 
+
+
     string mode;
     string wind;
     ParameterManager::get("symbol_position_mode", mode);
