@@ -37,7 +37,7 @@ namespace magics {
 class NoMagnifierVisitor : public SceneVisitor, public MagnifierLayout {
 public:
     NoMagnifierVisitor();
-    virtual ~NoMagnifierVisitor();
+    virtual ~NoMagnifierVisitor() override;
 
     virtual void set(const XmlNode&) { MagLog::dev() << "(const XmlNode&)---> to be checked!...\n"; }
     virtual bool accept(const string&) { return false; }
@@ -45,17 +45,17 @@ public:
         MagLog::dev() << "(const map<string, string&)---> to be checked!...\n";
     }
     virtual void toxml(ostream&, int = 0) const {}
-    virtual NoMagnifierVisitor* clone() const {
+    virtual NoMagnifierVisitor* clone() const override {
         MagLog::dev() << "(const map<string, string&)---> to be checked!...\n";
         return new NoMagnifierVisitor();
     }
-    void visit(magics::BasicSceneObject&) {}
+    void visit(magics::BasicSceneObject&) override {}
     virtual void add(const PaperPoint&) {}
     virtual void owner(BasicSceneObject* owner) { owner_ = owner; }
 
 protected:
     //! Method to print string about this class on to a stream of type ostream (virtual).
-    virtual void print(ostream&) const;
+    virtual void print(ostream&) const override;
     BasicSceneObject* owner_;
 
 
@@ -77,26 +77,26 @@ class MagnifierVisitor : public NoMagnifierVisitor, public MagnifierVisitorAttri
 public:
     MagnifierVisitor();
 
-    virtual ~MagnifierVisitor();
-    void visit(BasicGraphicsObjectContainer&);
-    virtual NoMagnifierVisitor* clone() const {
+    virtual ~MagnifierVisitor() override;
+    void visit(BasicGraphicsObjectContainer&) override;
+    virtual NoMagnifierVisitor* clone() const override {
         MagnifierVisitor* visitor = new MagnifierVisitor();
         visitor->owner_           = owner_;
         visitor->copy(*this);
         return visitor;
     }
-    virtual void set(const XmlNode& node) { MagnifierVisitorAttributes::set(node); }
-    virtual void set(const map<string, string>& map) { MagnifierVisitorAttributes::set(map); }
-    void redisplay(const BaseDriver& driver) const;
-    void redisplay(const BaseDriver& driver, vector<PaperPoint>&, float, float) const;
-    void visit(magics::BasicSceneObject& object) { object.visit(*this); }
-    void add(const PaperPoint&);
+    virtual void set(const XmlNode& node) override { MagnifierVisitorAttributes::set(node); }
+    virtual void set(const map<string, string>& map) override { MagnifierVisitorAttributes::set(map); }
+    void redisplay(const BaseDriver& driver) const override;
+    void redisplay(const BaseDriver& driver, vector<PaperPoint>&, float, float) const override;
+    void visit(magics::BasicSceneObject& object) override { object.visit(*this); }
+    void add(const PaperPoint&) override;
     void addMore(const PaperPoint&);
 
 
 protected:
     //! Method to print string about this class on to a stream of type ostream (virtual).
-    virtual void print(ostream&) const;
+    virtual void print(ostream&) const override;
     mutable TextSymbol* values_;
     mutable Symbol* more_;
 };
