@@ -43,8 +43,10 @@ VisualAction::~VisualAction() {
             delete *visdef;
         *visdef = 0;
     }
-    if (layer_)
-        delete layer_;
+    if (layer_) {
+        // FIXME: Double delete
+        // delete layer_;
+    }
 }
 
 /*!
