@@ -137,13 +137,9 @@ void Polyline::newHole(const Polyline& poly) {
 struct ReprojectHelper {
     ReprojectHelper(const Transformation& transformation) : transformation_(transformation) {}
     const Transformation& transformation_;
-    bool operator()(PaperPoint& point) { return !transformation_.fast_reproject(point.x_, point.y_); }
-    /*
-    bool operator()(PaperPoint& point) {
-        transformation_.fast_reproject(point.x_, point.y_);
-        return false;
-    };
-    */
+
+
+    bool operator()(PaperPoint& point) { return !transformation_.fast_reproject(point.x_, point.y_); };
 };
 
 
@@ -182,10 +178,18 @@ void Polyline::intersect(const Polyline& poly, vector<Polyline*>& out) const {
     MagClipper::clip(poly, *this, out);
 }
 
+bool Polyline::skinny_ = false;
+
 
 void feed(const deque<PaperPoint>& points, const Polyline& box, vector<Polyline*>& out) {
     Polyline* poly = new Polyline();
     for (auto p = points.begin(); p != points.end(); ++p) {
+        if (Polyline::skinny_) {
+            poly->push_back(*p);
+
+            continue;
+        }
+
         if (!box.in(*p) || p->border()) {
             if (poly->size()) {
                 out.push_back(poly);
