@@ -23,10 +23,10 @@ namespace magics {
 class ProgressTask : public Task {
 public:
     ProgressTask();
-    virtual ~ProgressTask();
+    virtual ~ProgressTask() override;
 
 protected:
-    virtual void print(ostream&) const;
+    virtual void print(ostream&) const override;
 
 private:
     // No copy allowed
