@@ -19,9 +19,9 @@
 #ifndef _TaylorProjection_H
 #define _TaylorProjection_H
 
-#include <TaylorProjectionAttributes.h>
-#include <Transformation.h>
-#include <XmlNode.h>
+#include "TaylorProjectionAttributes.h"
+#include "Transformation.h"
+#include "XmlNode.h"
 
 namespace magics {
 
@@ -35,24 +35,24 @@ namespace magics {
 class TaylorProjection : public Transformation, public TaylorProjectionAttributes {
 public:
     TaylorProjection();
-    ~TaylorProjection();
+    ~TaylorProjection() override;
 
     /*!
       \brief sets  from an XML node
     */
-    void set(const XmlNode& node) {
+    void set(const XmlNode& node) override {
         Transformation::set(node);
         TaylorProjectionAttributes::set(node);
     }
     /*!
       \brief sets  from a map
     */
-    void set(const map<string, string>& map) {
+    void set(const map<string, string>& map) override {
         Transformation::set(map);
         TaylorProjectionAttributes::set(map);
     }
 
-    virtual Transformation* clone() const {
+    virtual Transformation* clone() const override {
         TaylorProjection* transformation = new TaylorProjection();
         transformation->copy(*this);
         return transformation;
@@ -61,52 +61,52 @@ public:
     /*!
     \\brief Initialise the projection
     */
-    virtual void init();
-    virtual void cleanPCEnveloppe();
+    virtual void init() override;
+    virtual void cleanPCEnveloppe() override;
     /*!
     \\brief
     */
-    virtual PaperPoint operator()(const UserPoint&) const;
+    virtual PaperPoint operator()(const UserPoint&) const override;
     /*!
     \\brief
     */
 
-    virtual PaperPoint operator()(const PaperPoint&) const;
+    virtual PaperPoint operator()(const PaperPoint&) const override;
     /*!
     \\brief
     */
-    virtual void revert(const PaperPoint&, UserPoint&) const;
+    virtual void revert(const PaperPoint&, UserPoint&) const override;
 
 
     /*!
     \\brief Does the projection needs the coastalines to be shifted!
     */
-    virtual bool needShiftedCoastlines() const;
+    virtual bool needShiftedCoastlines() const override;
     /*!
     \\brief set the aspect ratio!
     */
-    virtual void aspectRatio(double&, double&);
+    virtual void aspectRatio(double&, double&) override;
     /*!
     \\brief set the bounding box!
     */
-    virtual void boundingBox(double&, double&, double&, double&) const;
+    virtual void boundingBox(double&, double&, double&, double&) const override;
 
     /*!
     \\brief return the xmin in user coordinates!
     */
-    virtual double getMinX() const;
+    virtual double getMinX() const override;
     /*!
     \\brief return the ymin in user coordinates!
     */
-    virtual double getMinY() const;
+    virtual double getMinY() const override;
     /*!
     \\brief return the xmax in user coordinates!
     */
-    virtual double getMaxX() const;
+    virtual double getMaxX() const override;
     /*!
     \\brief return the ymax in user coordinates!
     */
-    virtual double getMaxY() const;
+    virtual double getMaxY() const override;
     /*!
     \\brief set the xmin in user coordinates!
     */
@@ -126,28 +126,28 @@ public:
     /*!
     \\brief return the xmin in projection coordinates!
     */
-    virtual double getMinPCX() const;
+    virtual double getMinPCX() const override;
     /*!
     \\brief return the ymin in projection coordinates!
     */
-    virtual double getMinPCY() const;
+    virtual double getMinPCY() const override;
     /*!
     \\brief return the xmax in projection coordinates!
     */
-    virtual double getMaxPCX() const;
+    virtual double getMaxPCX() const override;
     /*!
     \\brief return the ymax in projection coordinates!
     */
-    virtual double getMaxPCY() const;
+    virtual double getMaxPCY() const override;
 
-    virtual Polyline& getPCBoundingBox() const;
-    virtual Polyline& getUserBoundingBox() const;
+    virtual Polyline& getPCBoundingBox() const override;
+    virtual Polyline& getUserBoundingBox() const override;
 
-    virtual void setDefinition(const string&);
+    virtual void setDefinition(const string&) override;
 
 protected:
     //! Method to print string about this class on to a stream of type ostream (virtual).
-    virtual void print(ostream&) const;
+    virtual void print(ostream&) const override;
 
 private:
     //! Copy constructor - No copy allowed
