@@ -87,7 +87,7 @@ private:
     MAGICS_NO_EXPORT void renderSimplePolygon(const Polyline& line) const;
     MAGICS_NO_EXPORT void renderText(const Text& text) const;
     MAGICS_NO_EXPORT void circle(const MFloat x, const MFloat y, const MFloat r, const int) const;
-    MAGICS_NO_EXPORT bool renderPixmap(MFloat, MFloat, MFloat, MFloat, int, int, unsigned char*, int, bool) const;
+    MAGICS_NO_EXPORT bool renderPixmap(const Pixmap&) const;
     MAGICS_NO_EXPORT bool renderCellArray(const Image& obj) const;
 
     MAGICS_NO_EXPORT MFloat setY(const MFloat y) const { return -y; }
