@@ -757,81 +757,14 @@ MAGICS_NO_EXPORT void KMLDriver::renderText(const Text& text) const {}
   param pixmap contents
 
 */
-MAGICS_NO_EXPORT bool KMLDriver::renderPixmap(MFloat x0, MFloat y0, MFloat x1, MFloat y1, int w, int h,
-                                              unsigned char* pixmap, int, bool, bool) const {
+MAGICS_NO_EXPORT bool KMLDriver::renderPixmap(const Pixmap& in) const {
     debugOutput("Start renderPixmap");
     if (render_) {
         if (kml_placemark_)
             closePlacemark();
 #ifndef HAVE_CAIRO
-#ifndef MAGICS_RASTER
         MagLog::warning() << "Image import is not implemented for the used driver!!!" << endl;
         return false;
-#else
-        MagLog::dev() << "KML driver Image import uses GD -> for better results use Cairo backend." << endl;
-        stringstream out;
-        out << 15 * kml_output_resource_list_.size();
-        const string filename = "KML_overlay_" + out.str() + "png";
-
-        pFile_ << "<GroundOverlay>\n";
-
-        const int a = (int)(transparency_ * 2.55);
-        pFile_ << "<styleUrl>#hiker-icon</styleUrl>\n"
-               << "<color>" << hex;
-        if (a > 15)
-            pFile_ << a;
-        else
-            pFile_ << "0" << a << dec;
-        pFile_ << "ffffff</color>\n"
-               << "<visibility>1</visibility>\n"
-               << "<color>" << hex;
-        if (a > 15)
-            pFile_ << a;
-        else
-            pFile_ << "0" << a << dec;
-        pFile_ << "FFFFFF</color>\n"
-               << "<Icon>\n"
-               << "<href>" << filename
-               << "</href>\n"
-               //		<< "<refreshMode>onInterval</refreshMode>\n"
-               //		<< "<refreshInterval>86400</refreshInterval>\n"
-               //		<< "<viewBoundScale>0.75</viewBoundScale>\n"
-               << "</Icon>\n"
-               << "<LatLonBox>\n"
-               << "   <north>" << y0 << "</north>\n"
-               << "   <south>" << y1 << "</south>\n"
-               << "   <east>" << x1 << "</east>\n"
-               << "   <west>" << x0 << "</west>\n"
-               << "   <rotation>0</rotation>\n"
-               << "</LatLonBox>\n";
-
-
-        gdImagePtr im    = gdImageCreateTrueColor(w, h);
-        unsigned char* p = pixmap;
-        gdImageColorAllocateAlpha(im, 255, 255, 255, 127);
-
-        for (int i = h - 1; i >= 0; i--) {
-            for (int j = 0; j < w; j++) {
-                const int r = (int)*(p++);
-                const int g = (int)*(p++);
-                const int b = (int)*(p++);
-                if (r * g * b >= 0.) {
-                    const int col = gdImageColorResolveAlpha(im, r, g, b, 0);
-                    gdImageSetPixel(im, w, h, col);
-                }
-            }
-        }
-        gdImageDestroy(im);
-        gdImageAlphaBlending(im, 1);
-        gdImageSaveAlpha(im, 1);  // save transparency
-
-        FILE* outFile = fopen(filename.c_str(), "wb");
-        gdImagePng(im, outFile);
-        fclose(outFile);
-        kml_output_resource_list_.push_back(filename);
-
-        pFile_ << "</GroundOverlay>\n";
-#endif
 #else
         stringstream out;
         out << 15 * kml_output_resource_list_.size();
@@ -862,14 +795,14 @@ MAGICS_NO_EXPORT bool KMLDriver::renderPixmap(MFloat x0, MFloat y0, MFloat x1, M
                //		<< "<viewBoundScale>0.75</viewBoundScale>\n"
                << "</Icon>\n"
                << "<LatLonBox>\n"
-               << "   <north>" << y0 << "</north>\n"
-               << "   <south>" << y1 << "</south>\n"
-               << "   <east>" << x1 << "</east>\n"
-               << "   <west>" << x0 << "</west>\n"
+               << "   <north>" << in.y0 << "</north>\n"
+               << "   <south>" << in.y1 << "</south>\n"
+               << "   <east>" << in.x1 << "</east>\n"
+               << "   <west>" << in.x0 << "</west>\n"
                << "   <rotation>0</rotation>\n"
                << "</LatLonBox>\n";
 
-        cairo_surface_t* surface_ = cairo_image_surface_create(CAIRO_FORMAT_ARGB32, w, h);
+        cairo_surface_t* surface_ = cairo_image_surface_create(CAIRO_FORMAT_ARGB32, in.w, in.h);
         cairo_t* cr_              = cairo_create(surface_);
 
         // \todo specify layer transparency
@@ -881,25 +814,24 @@ MAGICS_NO_EXPORT bool KMLDriver::renderPixmap(MFloat x0, MFloat y0, MFloat x1, M
         cairo_paint(cr_);
         //	cairo_restore (cr_);
 
-        unsigned char* p = pixmap;
-        const MFloat dx  = (x1 - x0) / w;
-        const MFloat dy  = -(y1 - y0) / h;  // Minus needed for Y axis correction
+        unsigned char* p = in.pixmap;
+        const MFloat dx  =  (in.x1 - in.x0) / in.w;
+        const MFloat dy  = -(in.y1 - in.y0) / in.h;  // Minus needed for Y axis correction
 
-        const MFloat X0 = x0;
-        const MFloat Y0 = y0;
+        const MFloat X0 = in.x0;
+        const MFloat Y0 = in.y0;
+        MFloat x0 = in.x0;
+        MFloat y0 = in.y0;
 
-        for (int i = h - 1; i >= 0; i--) {
-            for (int j = 0; j < w; x0 += dx, j++) {
+        for (int i = in.h - 1; i >= 0; i--) {
+            for (int j = 0; j < in.w; x0 += dx, j++) {
                 const MFloat r = *(p++);
                 const MFloat g = *(p++);
                 const MFloat b = *(p++);
 
                 if ((r * g * b) >= 0.) {
                     cairo_set_source_rgba(cr_, r, g, b, 0.5);
-
-                    const MFloat x0 = X0 + (j * dx) + .5;
-                    const MFloat y0 = Y0 + (i * dy) + .5;
-                    cairo_rectangle(cr_, x0, y0, dx, -dy);
+                    cairo_rectangle(cr_, (X0 + (j * dx) + .5), (Y0 + (i * dy) + .5), dx, -dy);
                     cairo_stroke_preserve(cr_);
                     cairo_fill(cr_);
                 }
