@@ -27,13 +27,14 @@
 #include <odc/Reader.h>
 
 
-#include "Timer.h"
 #include "OdaDecoder.h"
+#include "Timer.h"
 
 #include "SciMethods.h"
 #include "TextVisitor.h"
 
 
+
 static int getOdbColumnIndex(odc::Reader::iterator&, const string&);
 
 int getOdbColumnIndex(odc::Reader::iterator& firstRowIt, const string& colName) {
@@ -97,14 +98,14 @@ void OdaGeoDecoder::decode(const Transformation& transformation) {
             int latIndex, lonIndex, valueIndex = -1;
 
             if ((latIndex = getOdbColumnIndex(it, latitude_)) == -1)
-                throw exception();
+                throw OdaMagException("Error in ODA decoder");
             if ((lonIndex = getOdbColumnIndex(it, longitude_)) == -1)
-                throw exception();
+                throw OdaMagException("Error in ODA decoder");
 
             if (value_.empty())
                 MagLog::info() << "No value is specified!" << endl;
             else if ((valueIndex = getOdbColumnIndex(it, value_)) == -1)
-                throw exception();
+                throw OdaMagException("Error in ODA decoder");
 
             MagLog::info() << "Indices: " << latIndex << " " << lonIndex << " " << valueIndex << endl;
 
@@ -189,14 +190,14 @@ void OdaGeoDecoder::decode() {
         int latIndex, lonIndex, valueIndex = -1;
 
         if ((latIndex = getOdbColumnIndex(it, latitude_)) == -1)
-            throw exception();
+            throw OdaMagException("Error in ODA decoder");
         if ((lonIndex = getOdbColumnIndex(it, longitude_)) == -1)
-            throw exception();
+            throw OdaMagException("Error in ODA decoder");
 
         if (value_.empty())
             MagLog::info() << "No value is specified!" << endl;
         else if ((valueIndex = getOdbColumnIndex(it, value_)) == -1)
-            throw exception();
+            throw OdaMagException("Error in ODA decoder");
 
         MagLog::info() << "Indices: " << latIndex << " " << lonIndex << " " << valueIndex << endl;
 
@@ -302,18 +303,18 @@ void OdaGeoDecoder::customisedPoints(const std::set<string>&, CustomisedPointsLi
         int latIndex, lonIndex, valueIndex = -1, xIndex, yIndex;
 
         if ((latIndex = getOdbColumnIndex(it, latitude_)) == -1)
-            throw exception();
+            throw OdaMagException("Error in ODA decoder");
         if ((lonIndex = getOdbColumnIndex(it, longitude_)) == -1)
-            throw exception();
+            throw OdaMagException("Error in ODA decoder");
         if (value_.empty())
             MagLog::info() << "No value is specified!" << endl;
         else if ((valueIndex = getOdbColumnIndex(it, value_)) == -1)
-            throw exception();
+            throw OdaMagException("Error in ODA decoder");
 
         if ((xIndex = getOdbColumnIndex(it, x_)) == -1)
-            throw exception();
+            throw OdaMagException("Error in ODA decoder");
         if ((yIndex = getOdbColumnIndex(it, y_)) == -1)
-            throw exception();
+            throw OdaMagException("Error in ODA decoder");
 
         MagLog::info() << "Indices: " << latIndex << " " << lonIndex << " " << valueIndex << endl;
 
@@ -397,19 +398,19 @@ void OdaGeoDecoder::customisedPoints(const Transformation& transformation, const
         int latIndex, lonIndex, valueIndex = -1, xIndex, yIndex;
 
         if ((latIndex = getOdbColumnIndex(it, latitude_)) == -1)
-            throw exception();
+            throw OdaMagException("Error in ODA decoder");
         if ((lonIndex = getOdbColumnIndex(it, longitude_)) == -1)
-            throw exception();
+            throw OdaMagException("Error in ODA decoder");
 
         if (value_.empty())
             MagLog::info() << "No value is specified!" << endl;
         else if ((valueIndex = getOdbColumnIndex(it, value_)) == -1)
-            throw exception();
+            throw OdaMagException("Error in ODA decoder");
 
         if ((xIndex = getOdbColumnIndex(it, x_)) == -1)
-            throw exception();
+            throw OdaMagException("Error in ODA decoder");
         if ((yIndex = getOdbColumnIndex(it, y_)) == -1)
-            throw exception();
+            throw OdaMagException("Error in ODA decoder");
 
         MagLog::info() << "Indices: " << latIndex << " " << lonIndex << " " << valueIndex << endl;
 
@@ -683,15 +684,15 @@ void OdaXYDecoder::customisedPoints(const Transformation& transformation, const
         int xIndex = -1, yIndex = -1, valueIndex = -1, xcIndex = -1, ycIndex = -1;
 
         if ((xIndex = getOdbColumnIndex(it, x_)) == -1)
-            throw exception();
+            throw OdaMagException("Error in ODA decoder");
         if ((yIndex = getOdbColumnIndex(it, y_)) == -1)
-            throw exception();
+            throw OdaMagException("Error in ODA decoder");
         if (!value_.empty() && (valueIndex = getOdbColumnIndex(it, value_)) == -1)
-            throw exception();
+            throw OdaMagException("Error in ODA decoder");
         if (!x_component_.empty() && (xcIndex = getOdbColumnIndex(it, x_component_)) == -1)
-            throw exception();
+            throw OdaMagException("Error in ODA decoder");
         if (!y_component_.empty() && (ycIndex = getOdbColumnIndex(it, y_component_)) == -1)
-            throw exception();
+            throw OdaMagException("Error in ODA decoder");
 
         MagLog::info() << "Indices: " << xIndex << " " << yIndex << " " << valueIndex << " " << xcIndex << " "
                        << xcIndex << endl;
@@ -758,15 +759,15 @@ void OdaXYDecoder::customisedPoints(const std::set<string>&, CustomisedPointsLis
         int xIndex = -1, yIndex = -1, valueIndex = -1, xcIndex = -1, ycIndex = -1;
 
         if ((xIndex = getOdbColumnIndex(it, x_)) == -1)
-            throw exception();
+            throw OdaMagException("Error in ODA decoder");
         if ((yIndex = getOdbColumnIndex(it, y_)) == -1)
-            throw exception();
+            throw OdaMagException("Error in ODA decoder");
         if (!value_.empty() && (valueIndex = getOdbColumnIndex(it, value_)) == -1)
-            throw exception();
+            throw OdaMagException("Error in ODA decoder");
         if (!x_component_.empty() && (xcIndex = getOdbColumnIndex(it, x_component_)) == -1)
-            throw exception();
+            throw OdaMagException("Error in ODA decoder");
         if (!y_component_.empty() && (ycIndex = getOdbColumnIndex(it, y_component_)) == -1)
-            throw exception();
+            throw OdaMagException("Error in ODA decoder");
 
         MagLog::info() << "Indices: " << xIndex << " " << yIndex << " " << valueIndex << " " << xcIndex << " "
                        << xcIndex << endl;
@@ -853,11 +854,11 @@ void OdaXYDecoder::decode(const Transformation& transformation) {
         int xIndex = -1, yIndex = -1, valueIndex = -1;
 
         if ((xIndex = getOdbColumnIndex(it, x_)) == -1)
-            throw exception();
+            throw OdaMagException("Error in ODA decoder");
         if ((yIndex = getOdbColumnIndex(it, y_)) == -1)
-            throw exception();
+            throw OdaMagException("Error in ODA decoder");
         if (!value_.empty() && (valueIndex = getOdbColumnIndex(it, value_)) == -1)
-            throw exception();
+            throw OdaMagException("Error in ODA decoder");
 
         MagLog::info() << "Indices: " << xIndex << " " << yIndex << " " << valueIndex << endl;
 
@@ -914,11 +915,11 @@ void OdaXYDecoder::decode() {
         int xIndex = -1, yIndex = -1, valueIndex = -1;
 
         if ((xIndex = getOdbColumnIndex(it, x_)) == -1)
-            throw exception();
+            throw OdaMagException("Error in ODA decoder");
         if ((yIndex = getOdbColumnIndex(it, y_)) == -1)
-            throw exception();
+            throw OdaMagException("Error in ODA decoder");
         if (!value_.empty() && (valueIndex = getOdbColumnIndex(it, value_)) == -1)
-            throw exception();
+            throw OdaMagException("Error in ODA decoder");
 
         MagLog::info() << "Indices: " << xIndex << " " << yIndex << " " << valueIndex << endl;
 
