@@ -389,6 +389,7 @@ void VerticalAxis::label(VerticalAxisVisitor& axis) {
 
        
 
+
         bool out = false;
 
         if (magCompare(label_position_, "inter_tick")) {
@@ -529,6 +530,25 @@ void VerticalAxis::title(VerticalAxisVisitor& out) {
     out.push_back(text);
 }
 
+void HorizontalAxis::highlight(DrawingVisitor& out) const {
+    if ( highlighted_values_.empty() )
+        return;
+    double bottom = out.minY();
+    double top    = out.maxY();
+    const Transformation& transformation = out.transformation();
+
+    for ( auto highlight = highlighted_values_.begin(); highlight != highlighted_values_.end(); ++highlight ) {
+        Polyline* high = new Polyline();
+        high->push_back(PaperPoint(transformation.x(*highlight), bottom));
+        high->push_back(PaperPoint(transformation.x(*highlight), top));
+        high->setColour(*highlighted_values_colour_);
+        high->setLineStyle(highlighted_values_style_);
+        high->setThickness(highlighted_values_thickness_);
+        out.push_back(high);
+    }
+}
+
+
 void HorizontalAxis::grid(DrawingVisitor& out) const {
     double bottom = out.minY();
     double top    = out.maxY();
@@ -597,6 +617,26 @@ void HorizontalAxis::grid(DrawingVisitor& out) const {
     }
 }
 
+void VerticalAxis::highlight(DrawingVisitor& out) const {
+    if ( highlighted_values_.empty() )
+        return;
+    double left  = out.minX();
+    double right = out.maxX();
+    const Transformation& transformation = out.transformation();
+
+    for ( auto highlight = highlighted_values_.begin(); highlight != highlighted_values_.end(); ++highlight ) {
+        Polyline* high = new Polyline();
+        high->push_back(PaperPoint(left, transformation.y(*highlight)));
+        high->push_back(PaperPoint(right, transformation.y(*highlight)));
+        high->setColour(*highlighted_values_colour_);
+        high->setLineStyle(highlighted_values_style_);
+        high->setThickness(highlighted_values_thickness_);
+        out.push_back(high);
+    }
+
+
+}
+
 void VerticalAxis::grid(DrawingVisitor& out) const {
     double left  = out.minX();
     double right = out.maxX();
