@@ -32,13 +32,13 @@ namespace magics {
 class ColourSelectionList : public ColourSelection, public ColourSelectionListAttributes {
 public:
     ColourSelectionList();
-    virtual ~ColourSelectionList();
-    virtual void set(map<string, string> map) { ColourSelectionListAttributes::set(map); }
+    virtual ~ColourSelectionList() override;
+    virtual void set(map<string, string> map) override { ColourSelectionListAttributes::set(map); }
     void prepare();
 
 protected:
     //! Method to print string about this class on to a stream of type ostream (virtual).
-    virtual void print(ostream&) const;
+    virtual void print(ostream&) const override;
 
 private:
     //! Copy constructor - No copy allowed
