@@ -59,7 +59,8 @@ public:
 };
 
 
-class ColourTechnique : public map<double, ColourInfo> {
+class ColourTechnique : public map<double, ColourInfo>, 
+    public ColourTechniqueAttributes {
 public:
     ColourTechnique();
     virtual ~ColourTechnique();
@@ -86,6 +87,9 @@ public:
     void visit(LegendVisitor&);
     ListPolicy getPolicy() const { return policy_; }
 
+    bool minOutOfBound() const { return minOutOfBound_; }
+    bool maxOutOfBound() const { return maxOutOfBound_; }
+
 protected:
     //! Method to print string about this class on to a stream of type ostream (virtual).
     virtual void print(ostream&) const;
@@ -94,6 +98,9 @@ protected:
     map<double, pair<double, double> > ranges_;
     double maxLevel_;
 
+    bool minOutOfBound_;
+    bool maxOutOfBound_;
+
     ListPolicy policy_;
 
 
@@ -124,6 +131,13 @@ public:
 
     void set(const ColourTechniqueInterface&) override;
 
+    virtual void copy(const PaletteColourTechnique&) {
+        PaletteColourTechniqueAttributes::copy(*this);
+        ColourTechniqueAttributes::copy(*this);
+    }
+
+
+
 
     virtual ColourTechnique* clone() const override {
         PaletteColourTechnique* object = new PaletteColourTechnique();
