@@ -34,7 +34,7 @@ class HiLo;
 class HiLoTechnique : public HiLoTechniqueAttributes {
 public:
     HiLoTechnique() {}
-    virtual ~HiLoTechnique() {}
+    virtual ~HiLoTechnique() override {}
     virtual HiLoTechnique* clone() {
         HiLoTechnique* object = new HiLoTechnique();
         object->copy(*this);
@@ -42,12 +42,12 @@ public:
     }
     virtual void operator()(const PaperPoint&, HiLo&) {}
     virtual void clear() {}
-    void set(const map<string, string>& map) { HiLoTechniqueAttributes::set(map); }
-    void set(const XmlNode& node) { HiLoTechniqueAttributes::set(node); }
+    void set(const map<string, string>& map) override { HiLoTechniqueAttributes::set(map); }
+    void set(const XmlNode& node) override { HiLoTechniqueAttributes::set(node); }
 
 protected:
     //! Method to print string about this class on to a stream of type ostream (virtual).
-    virtual void print(ostream&) const {}
+    virtual void print(ostream& s) const override { s << "HiLoTechnique[]"; }
 
 private:
     //! Copy constructor - No copy allowed
