@@ -20,7 +20,6 @@
 
 
 #include "IsoPlot.h"
-#include "AutoLock.h"
 #include "Colour.h"
 #include "Factory.h"
 #include "Histogram.h"
@@ -28,15 +27,16 @@
 #include "LegendVisitor.h"
 #include "MagClipper.h"
 #include "MatrixHandler.h"
-#include "ThreadControler.h"
 #include "Timer.h"
 #include "UserPoint.h"
 
+#include <thread>
 
 namespace magics {
 
 
-static MutexCond producerMutex_;
+static std::mutex producer_mutex_;
+static std::condition_variable producer_cond_;
 
 IsoPlot::IsoPlot() {
     setTag("isoline");
@@ -512,11 +512,13 @@ public:
     IsoPlot& parent_;
     CellBox& cell_;
     bool more_;
-    MutexCond cond_;
+
+    std::mutex mutex_;
+    std::condition_variable cond_;
 };
 
 
-class IsoProducer : public Thread {
+class IsoProducer {
 public:
     IsoProducer(int n, IsoProducerData& data) : n_(n), objects_(data) {}
     void run() {
@@ -1133,15 +1135,15 @@ void IsoPlot::isoline(Cell& cell, CellBox* parent) const {
                     // We send it to a thread!
                     const int t = (*l) % threads_;
                     {
-                        AutoLock<MutexCond> lockproducer(producerMutex_);
+                        std::unique_lock<std::mutex> lockproducer(producer_mutex_);
                         {
-                            AutoLock<MutexCond> lock(segments_[t]->cond_);
+                            std::unique_lock<std::mutex> lock(segments_[t]->mutex_);
                             segments_[t]->segments_.push_back(
                                 make_pair(levels_[*l], std::make_pair(make_pair(x1, y1), std::make_pair(x2, y2))));
                             if (segments_[t]->segments_.size() >= 2000)
-                                segments_[t]->cond_.signal();
+                                segments_[t]->cond_.notify_one();
                         }
-                        producerMutex_.signal();
+                        producer_cond_.notify_one();
                     }
                 }
 
@@ -1153,10 +1155,10 @@ void IsoPlot::isoline(Cell& cell, CellBox* parent) const {
 
             }  // end of levels...
 
-
-            box->reshape(parent);
-            delete box;
-
+            if (box) {
+                box->reshape(parent);
+                delete box;
+            }
 
         }  // step to next triangle
     }
@@ -1173,6 +1175,15 @@ inline bool getEnv(const string& name, bool def) {
     return def;
 }
 
+template <class T>
+void run(T* p, std::exception_ptr* eptr) {
+    try {
+        p->run();
+    }
+    catch (...) {
+        *eptr = current_exception();
+    }
+}
 
 void IsoPlot::isoline(MatrixHandler& data, BasicGraphicsObjectContainer& parent) {
     const Transformation& transformation = parent.transformation();
@@ -1203,15 +1214,15 @@ void IsoPlot::isoline(MatrixHandler& data, BasicGraphicsObjectContainer& parent)
     }
     if (last != end)
         levels_.push_back(*last);
-    while (level != end && *level < max) {
+    while (level != end) {
         levels_.push_back(*level);
         ++level;
     }
-    if (level != end) {
-        levels_.push_back(*level);
-    }
-    else
+
+
+    if (levels_.back() != max) {
         levels_.push_back(max);
+    }
 
 
     missing_ = data.missing();
@@ -1246,25 +1257,27 @@ void IsoPlot::isoline(MatrixHandler& data, BasicGraphicsObjectContainer& parent)
             threads_ = 4;
     }
 
-
     vector<IsoHelper*> consumers_;
     vector<IsoProducer*> producers_;
 
     {
         Timer timer("Threading", "Threading");
-        AutoVector<ThreadControler> consumers;
-        AutoVector<ThreadControler> producers;
+
+        std::vector<std::exception_ptr> exceptions(threads_ + view.size(), nullptr);
+        AutoVector<std::thread> consumers;
+        AutoVector<std::thread> producers;
         segments_.clear();
         colourShapes_.clear();
         lines_.clear();
 
+        int e = 0;
+
         for (int c = 0; c < threads_; c++) {
             vector<Polyline*>* lines = new vector<Polyline*>();
             lines_.push_back(lines);
             segments_.push_back(new IsoData());
             consumers_.push_back(new IsoHelper(c, *lines, *(segments_.back())));
-            consumers.push_back(new ThreadControler(consumers_.back(), false));
-            consumers.back()->start();
+            consumers.push_back(new std::thread(run<IsoHelper>, consumers_.back(), &exceptions[e++]));
         }
 
         view.split(threads_);
@@ -1277,25 +1290,34 @@ void IsoPlot::isoline(MatrixHandler& data, BasicGraphicsObjectContainer& parent)
             IsoProducerData* data = new IsoProducerData(shading_->shadingMode(), *this, *(view[i]));
             datas.push_back(data);
             producers_.push_back(new IsoProducer(c, *data));
-            producers.push_back(new ThreadControler(producers_.back(), false));
-            producers.back()->start();
+            exceptions.push_back(nullptr);
+            producers.push_back(new std::thread(run<IsoProducer>, producers_.back(), &exceptions[e++]));
             c++;
         }
 
-        for (auto& producer : producers)
-            producer->wait();
+        for (auto& producer : producers) {
+            producer->join();
+        }
 
         // No more
         {
             for (int i = 0; i < threads_; i++) {
-                AutoLock<MutexCond> lock(segments_[i]->cond_);
+                std::unique_lock<std::mutex> lock(segments_[i]->mutex_);
                 segments_[i]->more_ = false;
-                segments_[i]->cond_.signal();
+                segments_[i]->cond_.notify_one();
             }
         }
 
-        for (auto& consumer : consumers)
-            consumer->wait();
+        for (auto& consumer : consumers) {
+            consumer->join();
+        }
+
+        // Check for exceptions
+        for (int i = 0; i < exceptions.size(); i++) {
+            if (exceptions[i]) {
+                rethrow_exception(exceptions[i]);
+            }
+        }
     }
 
 
@@ -1434,13 +1456,13 @@ void IsoPlot::visit(Data& data, LegendVisitor& legend) {
     if (magCompare(legend_special_, "spaghetti")) {
         Polyline* blue = new Polyline();
         blue->setColour(Colour("blue"));
-        blue->setLineStyle(M_DASH);
+        blue->setLineStyle(LineStyle::DASH);
         Polyline* red = new Polyline();
         red->setColour(Colour("red"));
-        red->setLineStyle(M_DASH);
+        red->setLineStyle(LineStyle::DASH);
         Polyline* grey = new Polyline();
         grey->setColour(Colour("grey"));
-        grey->setLineStyle(M_SOLID);
+        grey->setLineStyle(LineStyle::SOLID);
         legend.add(new DoubleLineEntry("Det", blue, 0));
         legend.add(new DoubleLineEntry("Control", red, 0));
         legend.add(new DoubleLineEntry("EPS members", grey, 0));
@@ -1824,14 +1846,14 @@ void IsoPlot::setThicknessAndStyle() {
         line_style_list_.insert(make_pair(*level, *style));
         ++thickness;
         if (thickness == rainbowThicknessList_.end()) {
-            if (rainbowThicknessListPolicy_ == M_LASTONE)
+            if (rainbowThicknessListPolicy_ == ListPolicy::LASTONE)
                 --thickness;
             else
                 thickness = rainbowThicknessList_.begin();
         }
         ++style;
         if (style == styles.end()) {
-            if (rainbowStyleListPolicy_ == M_LASTONE)
+            if (rainbowStyleListPolicy_ == ListPolicy::LASTONE)
                 --style;
             else
                 style = styles.begin();
