@@ -129,20 +129,15 @@ public:
 
     virtual bool needClipping() override { return (*this->technique_).needClipping(); }
     virtual bool operator()(LevelSelection& list) override {
-        LevelSelection filter;
-        for (LevelSelection::const_iterator level = list.begin(); level != list.end(); ++level)
-            if (this->min_ <= *level && *level <= this->max_)
-                filter.push_back(*level);
 
 
-        (*this->colourMethod_).prepare(list, filter);
+        (*this->colourMethod_).prepare(list, list);
+
+        if (!list.empty() && (list.back() == list.front()))
+            list.push_back(list.front());
 
 
-        if (!filter.empty() && (filter.back() == filter.front()))
-            filter.push_back(filter.front());
-
-
-        return (*this->technique_).prepare(filter, *this->colourMethod_);
+        return (*this->technique_).prepare(list, *this->colourMethod_);
     }
     // returns true, if the contouring lines have to be created... False, is the shading is finished...
     virtual void visit(LegendVisitor& legend) override {
