@@ -140,7 +140,7 @@ void Style::match(const Value& value) {
         if (method != methods_.end())
             (this->*method->second)(entry->second);
         else
-            MagLog::warning() << entry->first << " is not a known keyword" << endl;
+            cout << entry->first << " is not a known keyword" << endl;
     }
 }
 
@@ -152,6 +152,7 @@ void Style::set(const ValueMap& object) {
         methods_["eccharts_layer"] = &Style::name;
         methods_["visdef"]         = &Style::style;
         methods_["scaling"]        = &Style::ignore;
+        methods_["description"]    = &Style::ignore;
     }
 
     for (auto entry = object.begin(); entry != object.end(); ++entry) {
@@ -159,7 +160,7 @@ void Style::set(const ValueMap& object) {
         if (method != methods_.end())
             (this->*method->second)(entry->second);
         else
-            MagLog::warning() << entry->first << " is not a known keyword" << endl;
+            cout << entry->first << " is not a known keyword" << endl;
     }
 }
 
@@ -221,19 +222,52 @@ void Palette::values(const Value& value) {
     }
 }
 
-void Palette::tags(const Value& value) {}
+void Palette::method(const Value& value) {
+   cout << "Palette::method" << endl;
+}
+
+void Palette::deprecated(const Value& value) {
+    ValueList values = value.get_value<ValueList>();
+
+    for (unsigned int i = 0; i < values.size(); i++) {
+        deprecated_.push_back(MagConfig::convert(values[i]));
+    }
+}
+void Palette::deprecatedReverse(const Value& value) {
+    ValueList values = value.get_value<ValueList>();
+
+    for (unsigned int i = 0; i < values.size(); i++) {
+        deprecatedReverse_.push_back(MagConfig::convert(values[i]));
+    }
+}
+
+void Palette::tags(const Value& value) {
+    ValueMap object = value.get_value<ValueMap>();
+    auto keywords = object.find("keywords");
+    if ( keywords != object.end() ) {
+        ValueList values = keywords->second.get_value<ValueList>();
+        for (unsigned int i = 0; i < values.size(); i++) {
+            string method = MagConfig::convert(values[i]);
+            if (method == "diverging")
+                method_ = "divergent";
+    }
+    }
+}
 
 void Palette::set(const ValueMap& object) {
+    method_ = "normal";
     if (methods_.empty()) {
         methods_["contour_shade_colour_list"] = &Palette::values;
         methods_["tags"]                      = &Palette::tags;
+        methods_["deprecated"]                = &Palette::deprecated;
+        methods_["deprecated_reversed"]       = &Palette::deprecatedReverse;
+        methods_["method"]       = &Palette::method;
+        methods_["keywords"]       = &Palette::method;
     }
     for (auto entry = object.begin(); entry != object.end(); ++entry) {
         map<string, SetMethod>::iterator method = methods_.find(entry->first);
         if (method != methods_.end())
             (this->*method->second)(entry->second);
-        else
-            MagLog::warning() << entry->first << " is not a known keyword" << endl;
     }
 }
 void PaletteLibrary::callback(const string& name, const Value& value) {
@@ -280,7 +314,7 @@ void UnitConvert::set(const ValueMap& object) {
         if (method != methods_.end())
             (this->*method->second)(entry->second);
         else
-            MagLog::warning() << entry->first << " is not a known keyword" << endl;
+            cout << entry->first << " is not a known keyword" << endl;
     }
 }
 void UnitsLibrary::callback(const string& name, const Value& value) {
@@ -504,3 +538,45 @@ void MagDefLibrary::callback(const string& name, const Value& value) {
 
     library_.insert(make_pair(name, def));
 }
+bool PaletteLibrary::find(string& name, Palette& out) {
+    map<string, Palette>::iterator palette = library_.find(name);
+
+    if (palette != library_.end()) {
+        out = palette->second;
+        return true;
+    }
+
+    
+    for ( auto p = library_.begin(); p != library_.end(); ++p) {
+        auto palette = p->second;
+    
+        auto deprecated = std::find(palette.deprecated_.begin(), palette.deprecated_.end(), name);
+
+        if ( deprecated != palette.deprecated_.end() ) {
+            out = palette;
+            MagLog::warning() << "The palette " << name << " is deprecated, using " << p->first << " instead" << endl;
+            MagLog::warning() << "Please update your code " << endl;
+            MagLog::warning() << "contour_shade_palette_name = '" << p->first << "'" << endl;
+            MagLog::warning() << "contour_shade_list_policy = 'dynamic'"  << endl;
+            name = string(p->first);
+            return true;
+        }
+        
+        auto deprecatedreverse = std::find(palette.deprecatedReverse_.begin(), palette.deprecatedReverse_.end(), name);
+
+        if ( deprecatedreverse != palette.deprecatedReverse_.end() ) {
+            out = palette;
+            reverse(out.colours_.begin(), out.colours_.end());
+            MagLog::warning() << "The reverse palette " << name << " is deprecated, using " << p->first << " instead" << endl;
+            MagLog::warning() << "Please update your code " << endl;
+            MagLog::warning() << "contour_shade_palette_name = '" << p->first << "'" << endl;
+            MagLog::warning() << "contour_shade_list_policy = 'dynamic'"  << endl;
+            MagLog::warning() << "contour_shade_colour_reverse_list = 'on'"  << endl;
+            name = string(p->first);
+            return true;
+        }
+       
+    }
+    return false;
+        
+}
\ No newline at end of file
